# Copyright 2026 The ODML Authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Deprecated litert-lm-cli package."""

from setuptools import setup
import sys

MESSAGE = """
================================================================================
ERROR: litert-lm-cli-nightly has been renamed to litert-lm-nightly.

The 'litert-lm-cli-nightly' package is now deprecated. Please install 'litert-lm-nightly' instead:

    pip install litert-lm-nightly
================================================================================
"""

if "sdist" not in sys.argv:
    # Only raise error during actual install, not when building sdist
    print(MESSAGE, file=sys.stderr)
    sys.exit(1)

setup(
    name="litert-lm-cli-nightly",
    version="0.9.1.dev20260330",
    description="Legacy LiteRT-LM CLI package. Please install litert-lm-nightly instead.",
    long_description=MESSAGE,
    long_description_content_type="text/plain",
    url="https://github.com/google-ai-edge/LiteRT-LM",
    author="The ODML Authors",
    license="Apache-2.0",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
    ],
)
